@@ -182,9 +182,9 @@ def django_instance_field_to_redis_value(
         ]
     elif django_field.__class__.__name__.startswith('Image') or django_field.__class__.__name__.startswith('File'):
         try:
-            redis_value = django_field_value.path
+            redis_value = django_field_value.file.path
         except:
-            print(django_field.__class__.__name__, django_field_value.__dict__)
+            redis_value = None
     return redis_value
 
 
